Simulation setup
================

Classes
-------

.. currentmodule:: ansys.edb.core.simulation_setup

.. autosummary::
   :toctree: _autosummary

   hfss_simulation_settings.HFSSSimulationSettings
   hfss_simulation_setup.HfssSimulationSetup
   hfss_simulation_settings.HFSSGeneralSettings
   hfss_simulation_settings.HFSSSettingsOptions
   hfss_simulation_settings.HFSSSolverSettings
   hfss_simulation_settings.HFSSAdvancedSettings
   hfss_simulation_settings.HFSSAdvancedMeshingSettings
   hfss_simulation_settings.HFSSDCRSettings
   hfss_pi_simulation_setup.HFSSPISimulationSetup
   hfss_pi_simulation_settings.HFSSPISimulationSettings
   hfss_pi_simulation_settings.HFSSPIGeneralSettings
   hfss_pi_simulation_settings.HFSSPISettingsOptions
   hfss_pi_simulation_settings.HFSSPISolverSettings
   hfss_pi_simulation_settings.HFSSPIAdvancedSettings
   adaptive_solutions.AdaptiveFrequency
   adaptive_solutions.BroadbandAdaptiveSolution
   adaptive_solutions.MatrixConvergenceData
   adaptive_solutions.MatrixConvergenceDataEntry
   adaptive_solutions.MultiFrequencyAdaptiveSolution
   adaptive_solutions.SingleFrequencyAdaptiveSolution
   mesh_operation.LengthMeshOperation
   mesh_operation.MeshOperation
   mesh_operation.SkinDepthMeshOperation
   simulation_settings.AdvancedMeshingSettings
   simulation_settings.AdvancedSettings
   simulation_settings.SettingsOptions
   simulation_settings.SimulationSettings
   simulation_settings.SolverSettings
   simulation_setup.SimulationSetup
   simulation_setup.SweepData
   simulation_setup.FreqSweepType
   simulation_setup.HFSSRegionComputeResource
   simulation_setup.InterpolatingSweepData
   simulation_setup.FrequencyData
   raptor_x_simulation_settings.RaptorXSimulationSettings
   raptor_x_simulation_settings.RaptorXGeneralSettings
   raptor_x_simulation_settings.RaptorXAdvancedSettings
   raptor_x_simulation_setup.RaptorXSimulationSetup
   siwave_dcir_simulation_settings.SIWaveDCIRSimulationSettings
   siwave_dcir_simulation_setup.SIWaveDCIRSimulationSetup
   siwave_simulation_settings.SIWaveSimulationSettings
   siwave_simulation_settings.SIWaveGeneralSettings
   siwave_simulation_settings.SIWaveAdvancedSettings
   siwave_simulation_settings.SIWaveDCSettings
   siwave_simulation_settings.SIWaveDCAdvancedSettings
   siwave_simulation_settings.SIWaveSParameterSettings
   siwave_simulation_setup.SIWaveSimulationSetup
   siwave_psi_simulation_settings.SIwavePSISimulationSettings
   siwave_psi_simulation_settings.SIwavePSIGeneralSettings
   siwave_psi_simulation_settings.SIwavePSINetProcessingSettings
   siwave_psi_simulation_settings.SIwavePSIPowerGroundNetsSettings
   siwave_psi_simulation_settings.SIwavePSISignalNetsSettings
   siwave_psi_simulation_setup.SIwavePSISimulationSetup
   q3d_simulation_settings.Q3DSimulationSettings
   q3d_simulation_settings.Q3DGeneralSettings
   q3d_simulation_settings.Q3DDCRLSettings
   q3d_simulation_settings.Q3DACRLSettings
   q3d_simulation_settings.Q3DCGSettings
   q3d_simulation_settings.Q3DAdvancedSettings
   q3d_simulation_settings.Q3DAdvancedMeshingSettings
   q3d_simulation_setup.Q3DSimulationSetup

Enums
-----

.. autosummary::
   :toctree: _autosummary

      simulation_setup.SimulationSetupType
      simulation_setup.Distribution
      hfss_simulation_settings.AdaptType
      hfss_simulation_settings.BasisFunctionOrder
      hfss_simulation_settings.SolverType
      hfss_pi_simulation_settings.HFSSPIModelType
      simulation_settings.ViaStyle
      simulation_settings.ModelType
      siwave_simulation_settings.SParamInterpolation
      siwave_simulation_settings.SParamExtrapolation
      siwave_simulation_settings.SParamDCBehavior
      siwave_psi_simulation_settings.SIwavePSISimulationPreference
      siwave_psi_simulation_settings.SIwavePSIModelType
      siwave_psi_simulation_settings.SurfaceRoughnessModel
      siwave_psi_simulation_settings.ImprovedLossModel
      siwave_psi_simulation_settings.ConductorModeling
      siwave_psi_simulation_settings.ErrorTolerance
      q3d_simulation_settings.Q3DSolutionOrder
      q3d_simulation_settings.Q3DSettingsType